# Phenological shifts in out-migrating juvenile Pacific Salmon
---

This dataset contains the rates of change in juvenile migration timing of 66 Pacific salmon populations ranging from Oregon to Alaska, the rates of change in timing of the initiation of spring phytoplankton bloom in nearby coastal regions, and covariates. Species represented in this dataset include coho salmon (Oncorhynchus kisutch), sockeye salmon (O. nerka), Chinook salmon (O. tshawytscha), pink salmon (O. gorbuscha), chum salmon (O. keta), and steelhead trout (O. mykiss). Rates of change in salmon phenology includes rate of change in peak date, and rate of change in range (number of days between 25th and 75th quantile of migration).

In general, juvenile salmon were intercepted during their migration to the ocean using a full fence weir, partial fence weir, rotary screw trap, incline plane trap, floating trap, or seine. Individuals were identified to species, counted, and released. All rates of change were calculated from datasets with at least 20 years of outmigration timing data, with at least 15 sampling days per year. The longest dataset began in 1951.

Data were collated, and rate of change in peak(mean), and range were determined from daily estimates using the R package phenomix.


## Description of the data and file structure

Column Header Definitions	
population -    population/watershed name where salmon reared or were captured 
species	-       salmon species. Underscore indicated primary life history type. So chinook_0 indicates chinook 0+(fry), vs chinook_1 indicates chinook 1+ (smolt). pink is seperated into odd (pink_odd) and even (pink_even) spawning year groups. 
pk_change	rate of change in days/year in peak phenology (-ve is earlier, +ve is later) for full dataset
pk_sd		standard deviation of rate of change in peak date
pk_lwrCI	lower bound of 95% confidence interval in the rate of change in peak date in days/year
pk_uprCI	upper bound of 95% confidence interval in the rate of change in peak date in days/year
rng_change	rate of change in the range (number of days between 25 and 75th quartile) in days/year. -ve = narrower, +ve = wider
rng_sd		standard deviation of rate of change in range
rng_lwrCI	lower bound of 95% confidence interval in the rate of change in range in days/year
rng_uprCI	upper bound of 95% confidence interval in the rate of change in range in days/year
pk99_change	rate of change in days/year in peak phenology ( -ve is earlier, +ve is later) for dataset subset from 1999 - to present
pk99_sd		standard deviation of rate of change in peak date for dataset subset from 1999 - to present
pk99_lwrCI	lower bound of 95% confidence interval in the rate of change in peak date for dataset subset from 1999 - to present in days/year
pk99_uprCI	upper bound of 95% confidence interval in the rate of change in peak date for dataset subset from 1999 - to present in days/year
rng99_change	rate of change in the range (number of days between 25 and 75th quartile) in days/year. -ve = narrower, +ve = wider for dataset subset from 1998 - to present
rng99_sd	standard deviation of rate of change in range for dataset subset from 1999 - to present
rng99_lwrCI	lower bound of 95% confidence interval in the rate of change in range for dataset subset from 1999 - to presentin days/year
rng99_uprCI	upper bound of 95% confidence interval in the rate of change in range for dataset subset from 1999 - to present in days/year
lon		logitude of collection site
lat		latitude of collection site
length		stream length upstream of collection site (km) (includes 1st order streams)
dist_oc		distance between collection site and the ocean (km)
area		watershed area upstream of the collection site (km2)
trap_el		elevation of the collection site (m)
min_el		minimum elevation of watershed above collection site (m)
mean_el		mean elevation of watershed above collection site (m)
max_el		maximum elevation of watershed above collection site (m)
yr_begin	first year of migration data collection
yr_end		last year of migration data collection
n_years		number of years that migration data was collected
work		collection site elevation divided by distance to the ocean (m/km)
section		coastal grid cell that the population corresponds to. Section 1 begins at 42nd parallel and sections move north by 2 degrees along the coast.
blm_chla_change	rate of change in spring phytoplankton bloom date (first day of the year that exceeds 5% of the mean chlorophyll a concentration for that year) in days/years for each grid cell/section
blm_chla_lwrCI	lower 95% confidence limit on rate of change in spring phytoplankton bloom date (first day of the year that exceeds 5% of the mean chlorophyll a concentration for that year) in days/years
blm_chla_uprCI	upper 95% confidence limit on rate of change in spring phytoplankton bloom date (first day of the year that exceeds 5% of the mean chlorophyll a concentration for that year) in days/years
M3_PPT		rate of change in the mean precipitation for the three months prior to peak outmigration (mm/year). Estimated using Climate NA v.5.21
M3_Tave		rate of change in the mean temperature for the three months prior to peak outmigration (oC/year). Estimated using Climate NA v.5.21
M3_Tmax		rate of change in the max temperature for the three months prior to peak outmigration(oC/year). Estimated using Climate NA v.5.21
M3_Tmin		rate of change in the min temperature for the three months prior to peak outmigration(oC/year). Estimated using Climate NA v.5.21
W3_PPT		rate of change in the mean winter (Dec -Feb) precipitation (mm/year). Estimated using Climate NA v.5.21
W3_Tave		rate of change in the mean winter (Dec -Feb) temperature (oC/year). Estimated using Climate NA v.5.21
W3_Tmax		rate of change in the maximum winter (Dec -Feb) temperature (oC/year). Estimated using Climate NA v.5.21
W3_Tmin		rate of change in the minimum winter (Dec -Feb) temperature (oC/year). Estimated using Climate NA v.5.21
S3_PPT		rate of change in the mean summer (Jul - Sept) precipitation (mm/year). Estimated using Climate NA v.5.21
S3_Tave		rate of change in the mean summer (Jul - Sept)  temperature (oC/year). Estimated using Climate NA v.5.21
S3_Tmax		rate of change in the maximum summer (Jul - Sept)  temperature (oC/year). Estimated using Climate NA v.5.21
S3_Tmin		rate of change in the minimum summer (Jul - Sept)  temperature (oC/year). Estimated using Climate NA v.5.21
F3_PPT		rate of change in the mean fall (Oct-Dec) precipitation (mm/year). Estimated using Climate NA v.5.21
F3_Tave		rate of change in the mean fall (Oct-Dec)  temperature (oC/year). Estimated using Climate NA v.5.21
F3_Tmax		rate of change in the maximum fall (Oct-Dec)  temperature (oC/year). Estimated using Climate NA v.5.21
F3_Tmin		rate of change in the minimum fall (Oct-Dec) temperature (oC/year). Estimated using Climate NA v.5.21
M3_PPT_er	sd of the rate of change in the mean precipitation for the three months prior to peak outmigration (mm/year). Estimated using Climate NA v.5.21
M3_Tave_er	sd of the rate of change in the mean temperature for the three months prior to peak outmigration (oC/year). Estimated using Climate NA v.5.21
M3_Tmax_er	sd of the rate of change in the max temperature for the three months prior to peak outmigration(oC/year). Estimated using Climate NA v.5.21
M3_Tmin_er	sd of the rate of change in the min temperature for the three months prior to peak outmigration(oC/year). Estimated using Climate NA v.5.21
W3_PPT_er	sd of the rate of change in the mean winter (Dec -Feb) precipitation (mm/year). Estimated using Climate NA v.5.21
W3_Tave_er	sd of the rate of change in the mean winter (Dec -Feb) temperature (oC/year). Estimated using Climate NA v.5.21
W3_Tmax_er	sd of the rate of change in the maximum winter (Dec -Feb) temperature (oC/year). Estimated using Climate NA v.5.21
W3_Tmin_er	sd of the rate of change in the minimum winter (Dec -Feb) temperature (oC/year). Estimated using Climate NA v.5.21
S3_PPT_er	sd of the rate of change in the mean summer (Jul - Sept) precipitation (mm/year). Estimated using Climate NA v.5.21
S3_Tave_er	sd of the rate of change in the mean summer (Jul - Sept)  temperature (oC/year). Estimated using Climate NA v.5.21
S3_Tmax_er	sd of the rate of change in the maximum summer (Jul - Sept)  temperature (oC/year). Estimated using Climate NA v.5.21
S3_Tmin_er	sd of the rate of change in the minimum summer (Jul - Sept)  temperature (oC/year). Estimated using Climate NA v.5.21
F3_PPT_er	sd of the rate of change in the mean fall (Oct-Dec) precipitation (mm/year). Estimated using Climate NA v.5.21
F3_Tave_er	sd of the rate of change in the mean fall (Oct-Dec)  temperature (oC/year). Estimated using Climate NA v.5.21
F3_Tmax_er	sd of the rate of change in the maximum fall (Oct-Dec)  temperature (oC/year). Estimated using Climate NA v.5.21
F3_Tmin_er	sd of the rate of change in the minimum fall (Oct-Dec) temperature (oC/year). Estimated using Climate NA v.5.21
hatchery_scale	Hatchery influence was determined using a scale where 0 indicated no hatchery in the watershed, no history of hatchery influence, and the nearest hatchery was in a distant basin > 100 km away; Category 1 had no current hatchery production of the target species in the watershed, but either (a) hatchery production in a nearby watershed < 100 km away allowing for a low level of hatchery-origin strays, (b) some within basin hatchery production of the target species in the distant past (e.g., > 25 years ago), or both (a) and (b); Category 2 had ongoing, within basin hatchery production of the target species in which natural-origin fish typically outnumbered hatchery-origin fish on the spawning grounds (proportion of Hatchery Origin Spawners [pHOS] < 50%), and/or the number of natural-origin juveniles were comparable to, or greater than, the number of juveniles released from the hatchery. All or nearly all hatchery-origin fish were marked. Conservation hatchery programs employing a high proportion of natural-origin broodstock would likely be in this category; Category 3: Long history (multiple decades) of large-scale hatchery production in which hatchery-origin fish routinely outnumbered hatchery origin fish on the spawning grounds (i.e., pHOS > 50%), and/or the number of fish released from hatcheries was considerably greater than the number of natural-origin juveniles.


## Code/Software

Phenomix R package was used to estimate rate of peak and range shifts. https://github.com/ericward-noaa/phenomix/tree/master/data